@@ -53,8 +53,8 @@ load_graph_draw (LoadGraph *g)
     gdk_draw_rectangle (g->pixmap,
 			g->disp->style->black_gc,
 			TRUE, 0, 0,
-			g->disp->allocation.width,
-			g->disp->allocation.height);
+			g->draw_width,
+			g->draw_height);
 
     for (i = 0; i < g->draw_width; i++)
 		g->pos [i] = g->draw_height;
@@ -65,7 +65,7 @@ load_graph_draw (LoadGraph *g)
 
 		for (i = 0; i < g->draw_width; i++) {
 	 	   gdk_draw_line (g->pixmap, g->gc,
-				   g->draw_width - i, g->pos[i],
+				  g->draw_width - i, g->pos[i],
 			 	  g->draw_width - i, g->pos[i] - g->data[i][j]);
 
 		    g->pos [i] -= g->data [i][j];
@@ -77,8 +77,8 @@ load_graph_draw (LoadGraph *g)
 		     g->pixmap,
 		     0, 0,
 		     0, 0,
-		     g->disp->allocation.width,
-		     g->disp->allocation.height);
+		     g->draw_width,
+		     g->draw_height);
 	
     for (i = 0; i < g->draw_width; i++)
 		memcpy (g->odata [i], g->data [i], g->data_size);
@@ -141,39 +141,12 @@ load_graph_unalloc (LoadGraph *g)
 static void
 load_graph_alloc (LoadGraph *g)
 {
-    PanelAppletOrient orient;
     int pixel_size, i;
 
     if (g->allocated)
 		return;
 
-    orient = panel_applet_get_orient (g->applet);
-    switch (orient)
-    {
-    case PANEL_APPLET_ORIENT_UP:
-    case PANEL_APPLET_ORIENT_DOWN:
-    {
-		g->orient = FALSE;
-		break;
-	}
-    case PANEL_APPLET_ORIENT_LEFT:
-    case PANEL_APPLET_ORIENT_RIGHT:
-    {
-		g->orient = TRUE;
-		break;
-	}
-    default:
-		g_assert_not_reached ();
-    }
-    
-    pixel_size = panel_applet_get_size (g->applet);
-    g_assert (pixel_size > 0);
-
-    g->pixel_size = pixel_size;
-
-	/* 36 is the pixel size for a "small" panel */
-/*    g->show_frame = pixel_size > 36;	*/
-	g->show_frame = 1;
+    g->show_frame = 1;
 
     g->data = g_new0 (guint *, g->draw_width);
     g->odata = g_new0 (guint *, g->draw_width);
@@ -196,30 +169,36 @@ load_graph_configure (GtkWidget *widget, GdkEventConfigure *event,
     LoadGraph *c = (LoadGraph *) data_ptr;
 	
     load_graph_unalloc (c);
-    
-    c->draw_width = c->disp->allocation.width;
-	c->draw_height = c->disp->allocation.height;;
-	
+
+    if (c->orient) {
+    	c->draw_width = c->pixel_size - 2;
+    	c->draw_height = c->size - 2;
+    }
+    else {
+    	c->draw_width = c->size - 2;
+    	c->draw_height = c->pixel_size - 2;
+    }
+
     load_graph_alloc (c);
 
     if (!c->pixmap)
-		c->pixmap = gdk_pixmap_new (c->disp->window,
-				    c->disp->allocation.width,
-				    c->disp->allocation.height,
+	c->pixmap = gdk_pixmap_new (c->disp->window,
+				    c->draw_width,
+				    c->draw_height,
 				    gtk_widget_get_visual (c->disp)->depth);
 
     gdk_draw_rectangle (c->pixmap,
 			widget->style->black_gc,
 			TRUE, 0,0,
-			widget->allocation.width,
-			widget->allocation.height);
+			c->draw_width,
+			c->draw_height);
     gdk_draw_pixmap (widget->window,
 		     c->disp->style->fg_gc [GTK_WIDGET_STATE(widget)],
 		     c->pixmap,
 		     0, 0,
 		     0, 0,
-		     c->disp->allocation.width,
-		     c->disp->allocation.height);
+		     c->draw_width,
+		     c->draw_height);
 	
     return TRUE;
     event = NULL;
@@ -247,7 +226,7 @@ load_graph_destroy (GtkWidget *widget, gpointer data_ptr)
 	
     load_graph_stop (g);
 
-	gtk_widget_destroy(widget);
+    gtk_widget_destroy(widget);
     object_list = g_list_remove (object_list, g);
     return;
     widget = NULL;
@@ -283,38 +262,65 @@ load_graph_new (PanelApplet *applet, guint n, gchar *label,
 		LoadGraphDataFunc get_data)
 {
     LoadGraph *g;
-
+    PanelAppletOrient orient;
+    
     g = g_new0 (LoadGraph, 1);
 
-	g->visible = visible;
-	g->name = name;
-	g->n = n;
-	g->speed  = speed;
+    g->visible = visible;
+    g->name = name;
+    g->n = n;
+    g->speed  = speed;
     g->size   = size;
+    g->pixel_size = panel_applet_get_size (applet);
     g->tooltip_update = FALSE;
     
-	if (!visible)
-		return g;
-
-	g->applet = applet;
+    g->applet = applet;
 		
-	g->main_widget = gtk_vbox_new (FALSE, FALSE);
+    g->main_widget = gtk_vbox_new (FALSE, FALSE);
 
     g->box = gtk_vbox_new (FALSE, FALSE);
+    
+    orient = panel_applet_get_orient (g->applet);
+    switch (orient)
+    {
+    case PANEL_APPLET_ORIENT_UP:
+    case PANEL_APPLET_ORIENT_DOWN:
+    {
+	g->orient = FALSE;
+	break;
+    }
+    case PANEL_APPLET_ORIENT_LEFT:
+    case PANEL_APPLET_ORIENT_RIGHT:
+    {
+	g->orient = TRUE;
+	break;
+    }
+    default:
+	g_assert_not_reached ();
+    }
+    
+    if (g->orient) {
+    	g->draw_width = g->pixel_size - 2;
+    	g->draw_height = g->size - 2;
+    }
+    else {
+    	g->draw_width = g->size - 2;
+    	g->draw_height = g->pixel_size - 2;
+    }
 
-	load_graph_alloc (g);	
+    load_graph_alloc (g);	
 		
-	if (g->show_frame)
-	{
-		g->frame = gtk_frame_new (NULL);
-		gtk_frame_set_shadow_type (GTK_FRAME (g->frame), GTK_SHADOW_ETCHED_IN);
-		gtk_container_add (GTK_CONTAINER (g->frame), g->box);
-		gtk_container_add (GTK_CONTAINER (g->main_widget), g->frame);
+    if (g->show_frame)
+    {
+	g->frame = gtk_frame_new (NULL);
+	gtk_frame_set_shadow_type (GTK_FRAME (g->frame), GTK_SHADOW_ETCHED_IN);
+	gtk_container_add (GTK_CONTAINER (g->frame), g->box);
+	gtk_container_add (GTK_CONTAINER (g->main_widget), g->frame);
     }
     else
     {
-		g->frame = NULL;
-		gtk_container_add (GTK_CONTAINER (g->main_widget), g->box);
+	g->frame = NULL;
+	gtk_container_add (GTK_CONTAINER (g->main_widget), g->box);
     }
 
     load_graph_load_config (g);
@@ -323,18 +329,15 @@ load_graph_new (PanelApplet *applet, guint n, gchar *label,
 
     g->timer_index = -1;
 
-	gtk_widget_show_all(GTK_WIDGET(g->applet));
 
-	if (g->orient)
-		gtk_widget_set_size_request (g->main_widget, g->pixel_size, g->size);
-    else
-		gtk_widget_set_size_request (g->main_widget, g->size, g->pixel_size);
-	
-	g->tooltips = gtk_tooltips_new();
-	gtk_tooltips_enable(g->tooltips);
-	
-	g->disp = gtk_drawing_area_new ();
-	gtk_widget_set_events (g->disp, GDK_EXPOSURE_MASK | GDK_ENTER_NOTIFY_MASK | GDK_LEAVE_NOTIFY_MASK);
+    gtk_widget_set_size_request (g->main_widget, g->pixel_size, g->size);
+    gtk_widget_set_size_request (g->main_widget, g->size, g->pixel_size);
+
+    g->tooltips = gtk_tooltips_new();
+   	
+    g->disp = gtk_drawing_area_new ();
+    gtk_widget_set_events (g->disp, GDK_EXPOSURE_MASK | GDK_ENTER_NOTIFY_MASK 
+    				    | GDK_LEAVE_NOTIFY_MASK);
 	
     g_signal_connect (G_OBJECT (g->disp), "expose_event",
 			G_CALLBACK (load_graph_expose), g);
@@ -343,10 +346,10 @@ load_graph_new (PanelApplet *applet, guint n, gchar *label,
     g_signal_connect (G_OBJECT(g->disp), "destroy",
 			G_CALLBACK (load_graph_destroy), g);
 	
-	gtk_box_pack_start_defaults (GTK_BOX (g->box), g->disp);    
-
+    gtk_box_pack_start_defaults (GTK_BOX (g->box), g->disp);    
+    gtk_widget_show_all(g->box);
     object_list = g_list_append (object_list, g);
-
+    
     return g;
     label = NULL;
 }
